@@ -914,7 +914,6 @@ class BugzillaProduct(Connection):
         self,
         product_names=None,
         product_types=None,
-        search_strings=None,
         include_fields="_default",
         product_handler=None,
         product_data=None,
@@ -923,16 +922,45 @@ class BugzillaProduct(Connection):
         """Constructor
 
         Args:
-            product_names (List[str]): list of product names or IDs
+            product_names (List[str]): search query or list of product names or IDs
             product_types (List[str]): list of the group of products to return
-            search_strings (List[str]): list of search strings
             include_fields (List[str]): list of include fields
             product_handler (Optional[function]): the handler to use with each retrieved product
             product_data (Optional): the data to use with the product handler
         """
         self.product_handler = Handler.get(product_handler, product_data)
 
-        if product_names is not None:
+        if isinstance(product_names, dict):
+            if include_fields or product_types:
+                params = product_names.copy()
+            else:
+                params = product_names
+
+            if include_fields:
+                if "include_fields" in params:
+                    if isinstance(include_fields, six.string_types):
+                        include_fields = [include_fields]
+                    if isinstance(params.get("include_fields"), six.string_types):
+                        params["include_fields"] = [params["include_fields"]]
+
+                    params["include_fields"] = list(
+                        set(params["include_fields"]).union(include_fields)
+                    )
+                else:
+                    params["include_fields"] = include_fields
+
+            if product_types:
+                if "type" in params:
+                    if isinstance(product_types, six.string_types):
+                        product_types = [product_types]
+                    if isinstance(params.get("type"), six.string_types):
+                        params["type"] = [params["type"]]
+
+                    params["type"] = list(set(params["type"]).union(product_types))
+                else:
+                    params["type"] = product_types
+
+        elif product_names is not None:
             if isinstance(product_names, six.string_types) or isinstance(
                 product_names, int
             ):
@@ -954,28 +982,23 @@ class BugzillaProduct(Connection):
                 ],
             }
 
-            super(BugzillaProduct, self).__init__(
-                BugzillaProduct.URL,
-                Query(BugzillaProduct.API_URL, params, self.__products_cb),
-                **kwargs
-            )
-        elif search_strings is not None:
-            if isinstance(search_strings, six.string_types):
-                search_strings = [search_strings]
+        elif product_types is not None:
+            params = {
+                "include_fields": include_fields,
+                "type": product_types,
+            }
 
-            queries = []
-            for search_string in search_strings:
-                queries.append(
-                    Query(
-                        BugzillaProduct.API_URL + "?" + search_string,
-                        handler=self.__products_cb,
-                    )
-                )
-
-            super(BugzillaProduct, self).__init__(
-                BugzillaProduct.URL, queries, **kwargs
+        else:
+            raise Exception(
+                "Should set one of the following: product_names or product_types"
             )
 
+        super(BugzillaProduct, self).__init__(
+            BugzillaProduct.URL,
+            Query(BugzillaProduct.API_URL, params, self.__products_cb),
+            **kwargs
+        )
+
     def get_header(self):
         header = super(BugzillaProduct, self).get_header()
         header["X-Bugzilla-API-Key"] = self.get_apikey()
